@@ -3,10 +3,9 @@ from .errors import (GibsonError, ProtocolError, ReplyError,
                      ExpectedANumber, MemoryLimitError, KeyLockedError)
 from .pool import GibsonPool, create_pool, create_gibson
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 # make pyflakes happy
-(GibsonConnection, create_connection,
-    GibsonError, ProtocolError, ReplyError, ExpectedANumber,
-    MemoryLimitError, KeyLockedError, GibsonPool,
+(GibsonConnection, create_connection, GibsonError, ProtocolError, ReplyError,
+    ExpectedANumber, MemoryLimitError, KeyLockedError, GibsonPool,
     create_pool, create_gibson)
